"use strict";

exports.__esModule = true;
exports.default = void 0;

var _helperPluginUtils = require("@babel/helper-plugin-utils");

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = (0, _helperPluginUtils.declare)((api, options, dirname) => {
  const {
    alias,
    path: relativeAliasedPath
  } = options;

  if (typeof alias !== "string") {
    throw new Error(`babel-plugin-codemod-aliased-imports expected an \`alias\` option of type string. Received ${alias} instead.`);
  }

  if (typeof relativeAliasedPath !== "string") {
    throw new Error(`babel-plugin-codemod-aliased-imports expected an \`path\` option of type string. Received ${relativeAliasedPath} instead.`);
  }

  return {
    name: "codemod-aliased-imports",
    visitor: {
      ImportDeclaration(node, state) {
        const importPath = node.get("source").node.value;

        const fileDirname = _path.default.dirname(state.filename);

        const absoluteImportPath = _path.default.resolve(fileDirname, importPath);

        const absoluteAliasedPath = _path.default.resolve(dirname, relativeAliasedPath);

        if (!node.aliased && absoluteImportPath.startsWith(absoluteAliasedPath)) {
          node.aliased = true;
          node.replaceWith(api.types.importDeclaration(node.get("specifiers"), api.types.stringLiteral(absoluteImportPath.replace(absoluteAliasedPath, alias))));
        }
      }

    }
  };
});

exports.default = _default;